@@ -41,8 +41,6 @@
 
 #define KDBUSADDONS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KDBUSADDONS_NO_DEPRECATED) && !defined(KDBUSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KDBUSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDBUSADDONS_NO_DEPRECATED
-#  define KDBUSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KDBUSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KDBUSADDONS_NO_DEPRECATED_WARNINGS
 #  define KDBUSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KDBUSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDBUSADDONS_DEPRECATED_WARNINGS_SINCE KDBUSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDBUSADDONS_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KDBUSADDONS_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KDBUSADDONS_DEPRECATED
-#  define KDBUSADDONS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KDBUSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KDBUSADDONS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KDBUSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KDBUSADDONS_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
